#
# spec file for package nano
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _version 2.4
Name:           nano
Version:        2.4.2
Release:        6.3
Summary:        Pico editor clone with enhancements
License:        GPL-3.0+
Group:          Productivity/Editors/Other
Url:            http://nano-editor.org/
Source0:        http://nano-editor.org/dist/v%{_version}/%{name}-%{version}.tar.gz
Source1:        http://nano-editor.org/dist/v%{_version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  file-devel
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
Requires(post): info
Requires(preun): info
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1230
BuildRequires:  groff-full
%else
BuildRequires:  groff
%endif
%if 0%{?suse_version} > 1140
BuildRequires:  makeinfo
%else
BuildRequires:  texinfo
%endif

%description
GNU nano is a small and friendly text editor. It aims to emulate
the Pico text editor while also offering a few enhancements.

%lang_package

%prep
%setup -q

# Remove build time references so build-compare can do its work.
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M')
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i "s/__TIME__/\"$FAKE_BUILDTIME\"/" src/nano.c
sed -i "s/__DATE__/\"$FAKE_BUILDDATE\"/" src/nano.c

%build
%configure \
  --disable-rpath \
  --enable-utf8
make %{?_smp_mflags}

%install
%make_install

# Move documents to a proper directory.
mkdir -p %{buildroot}%{_docdir}/
mv -f %{buildroot}%{_datadir}/doc/%{name}/ %{buildroot}%{_docdir}/%{name}/

%find_lang %{name} --with-man --all-name

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{?ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{?ext_info}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog ChangeLog.pre-2.1 COPYING COPYING.DOC NEWS README THANKS TODO UPGRADE
%doc %{_docdir}/nano/
%exclude %{_docdir}/%{name}/*/
%{_bindir}/nano
%{_bindir}/rnano
%{_datadir}/nano/
%{_infodir}/nano.info%{?ext_info}
%{_mandir}/man1/nano.1%{?ext_man}
%{_mandir}/man1/rnano.1%{?ext_man}
%{_mandir}/man5/nanorc.5%{?ext_man}

%files lang -f %{name}.lang
%defattr(-,root,root)
%doc %{_docdir}/%{name}/*/

%changelog
* Mon Jul  6 2015 astieger@suse.com
- GNU nano 2.4.2:
  * ability to resize when in modes other than the main editing window
  * proper displaying of invalid UTF-8 bytes
  * new syntax definitions for Elisp, Guile, and PostgreSQL
  * better display of shortcuts in the help menu and file browser
* Thu Apr 16 2015 astieger@suse.com
- GNU nano 2.4.1:
  * several fixes for issues with the file browser menu
  * linter and formatter functions fixes
  * spell checker fixes
  * fixes to undo/redo with some specific marked-cutting situations
  * small improvements to the color syntax highlighting definitions
* Sat Mar 28 2015 mpluskal@suse.com
- Add gpg signature
* Mon Mar 23 2015 sor.alexei@meowr.ru
- Update to 2.4.0:
  * doc/nanorc.sample.in: Remove ‘undo’ section which is now obsolete.
  * doc/syntax/nanorc.nanorc: Remove 'undo' from the valid options.
  * doc/texinfo/nano.texi, doc/man/nanorc.5: Typo fix.
  * src/global.c (add_to_sclist): Remove the now unused and unneeded
    addition ability from this builder function of the shortcut list.
  * src/global.c (strtokeytype): Move this to a better place.
  * src/global.c (first_sc_for): Move this too to a better place.
  * src/prompt.c (do_yesno_prompt): Use the new and more direct
    func_from_key() wrapper instead of get_shortcut().
  * src/text.c (do_linter): Likewise.
  * src/files.c (do_insertfile, do_writeout): Likewise.
  * src/files.c (do_insertfile): Adjust some indentation.
  * src/prompt.c (do_statusbar_input), src/browser.c (do_browser):
    Reorder a few things, and adjust some whitespace.
  * doc/man/nano.1, doc/man/rnano.1: Separate short and long option
    by a comma instead of putting the long one between parentheses.
    And showing the required quotes around the argument of -Q.
  * doc/texinfo/nano.texi: Standardize the formatting of command-line
    options -- each one separately. Also add some more markup.
  * doc/man/nano.1, doc/man/rnano.1: Tweak the formatting a bit so
    that po4a will create a nicer POT file.
  * doc/man/nanorc.5: Improve some of the wordings and formatting.
  * doc/syntax/nanorc.nanorc: Remove a mistaken OR which causes a
    'Bad regex, empty (sub)expression' error on some systems.
  * doc/texinfo/nano.texi: Improve some wordings and formatting.
  * src/text.c (do_justify): Replace the old get_shortcut() wrapper
    with the new func_from_key().
  * doc/syntax/{perl,python,ruby,sh}.nanorc: Recognize also header
    lines of the form "#!/usr/bin/env thing" besides "#!/bin/thing".
  * doc/syntax/spec.nanorc: Colorize %%pretrans and %%posttrans fully.
  * src/files.c (do_lockfile): Gettextize the "File being edited"
    prompt, and improve its wording.
  * src/winio.c (do_credits): Remove the names of past translators
    from the Easter-egg scroll.
  * THANKS: Add a missing historical translator name.
  * src/winio.c (do_credits): Add Mark to the scroll, for all his
    undo work, colouring nano's interface, and other patches.
  * New formatter code to support syntaxes like
    go which have tools to automatically lint and reformat the text
    for you (gofmt), which is lovely. rcfile option formatter,
    function text.c:do_formatter() and some other calls.
  * src/files.c (open_buffer): Check here for locking and properly
    handle choosing to not open a file when locked instead of in
    open_file().
  * src/winio.c (do_credits): Add a general entry for all translators.
  * src/files.c (write_lockfile): Avoid writing uninitialized bytes
    to the lock file -- a simple null_at() would not initialize the
    buffer.
  * src/files.c (do_lockfile): Make sure that 'lockprog' and
    'lockuser' are terminated -- strncpy() does not guarantee that
    on its own.
  * src/files.c (do_lockfile): Avoid printing a wrong PID on the
    status bar due to treating serialized PID bytes as signed
    integers.
  * src/files.c (write_lockfile): Do not trim the nano version
    number -- snprintf() counts the trailing zero into the size limit.
  * src/cut.c (do_cut_text): Make sure to set modified even when
    using --enable-tiny.
  * src/file.c (do_lockfile): Also show the name of the affected file
    when finding a lock file, for when many files are opened at once.
  * src/file.c (do_lockfile): The user does the editing, not the editor.
  * doc/syntax/sh.nanorc: Recognize also dash, openrc and runscript.
  * README: Fix the explanation of how to subscribe to a mailing list.
  * doc/syntax/{java,lua,python,ruby}.nanorc: Wrap some overlong lines.
  * src/rcfile.c (parse_binding): Add an exception for do_toggle() as
    rebinding toggles broke with r5022. (Fixed in r5134.)
  * doc/man/nanorc.5, doc/texinfo/nano.texi: Add a note about the
    inherent imperfection of using regular expressions for syntax
    highlighting.
  * doc/man/nanorc.5: Improve the indentation of some lists.
  * doc/man/nanorc.5, doc/texinfo/nano.texi: Remove the mistaken
    square brackets around the arguments of "header" and "magic" --
    those arguments are not optional. Also add "formatter" to the
    texinfo document, and slightly improve its punctuation.
  * src/proto.h, src/nano.c: Fix compilation with --enable-tiny plus
  - -enable-nanorc.
  * src/rcfile.c (parse_binding): Fix the rebinding of toggles.
  * doc/man/{nano.1,rnano.1,nanorc.5}, doc/texinfo/nano.texi: Update
    years and version numbers in the docs in anticipation of a release.
  * src/nano.c (version): Drop compile time from version information
    to enable a reproducible build.
  * src/nano.c (renumber): Get out if there is nothing to renumber,
    to prevent do_undo() from falling over trying to renumber emptiness.
  * src/text.c (do_formatter): Fix a message plus a few comments.
  * src/text.c (do_alt_speller): Do not set the modified flag when
    an external spell checker didn't make any changes.
  * src/nano.c (finish_stdin_pager, cancel_stdin_pager, stdin_pager):
    Normalize the whitespace, remove an old comment, and place another
    one better.
  * src/text.c (do_undo): Make a message equal to another one. It
    was mistakenly changed in r4950. (This is translation-neutral.)
  * src/global.c (shortcut_init): Keep related items together in the
    ^G help screen.
  * src/text.c (do_alt_speller): Restore the positions of the mark
    and the cursor in a better way: to the columns where they were.
  * src/text.c (do_alt_speller): Remove some leftovers.
  * src/search.c: Place some comments better and unwrap some lines.
  * src/chars.c (move_mbleft): Start looking for a multibyte char
    not at the start of the string, but only as far back as such a
    char can possibly be. Change suggested by Mark Majeres.
  * src/search.c (findnextstr): Step backward or forward not simply
    one byte but one character (possibly multibyte).
  * src/winio.c (edit_redraw): Do not center the current line when
    smooth scrolling is used.
- Do less manually in spec.
* Tue Sep 16 2014 asterios.dramis@gmail.com
- Update to version 2.3.6:
  * Fix for installing internationalization files.
  * Documentation (in particular man page) fixes.
  * Few touch ups to syntax highlighting definitions.
  From version 2.3.5:
  * Many visible and under-the-hood fixes for components such as file locking,
    more fixes to the undo system, and you no longer have to explicitly ask
    nano to have undo/redo support as it now defaults to being enabled.
  * Better handling of --tempfile mode.
  * Better handling of command line arguments when also attempting to specify
    +<line number>.
  From version 2.3.4:
  * Small number of fixes, but in particular allows nano to compile on non-UTF8
    curses implementations (i.e. libncursesw).
  * Small fixes to the undo implementation.
  * Small fixes to the default syntax config.
  From version 2.3.3:
  * Many improvements to the core system, including substantial improvements to
    the undo/redo code, UTF-8 handling, the configure script, and display of
    shortcuts on very wide terminals.
  * Ability to read named pipes (--noread), as well as linter support (see the
    nanorc man page for details).
  * Much improved syntax highlighting code, and configurations for JSON,
    texinfo, Go, and a default syntax for catch all highlighting.
  * Ability to set the color of the title bar, status bar, and shortcut keys
    (e.g. "^X") and their descriptions (see the nanorc man page for details).
  * Lots of other fixes.
- Added new build requirements groff-full, makeinfo and pkg-config.
* Sat Mar 23 2013 asterios.dramis@gmail.com
- Update to version 2.3.2:
  * vim-style file locking (though not backup/restore), useful when using nano
    in a multi-editor environment.
  * Additional support for word boundary checking when cross compiling.
  * Fixes for trying to go to an invalid line number.
  * Documentation tweaks.
* Wed May 11 2011 asterios.dramis@gmail.com
- Update to version 2.3.1:
  * Some fixes for the new libmagic code.
  * Fix for improper character counts when using auto-indent.
  * New syntax highlighting definitions for RPM spec and lua files.
- Spec file updates:
  * Simplified License: to GPLv3+ which is the main license.
- Removed nano-no-build-date.patch and added a fix inside the spec file.
* Sun Feb 27 2011 asterios.dramis@gmail.com
- Update to version 2.3.0:
  * libmagic support for syntax highlighting has been added on top of the
    existing file extension and header support already available.
  * Cursor position can be saved between editing sessions with the -P or
  - -poslog command line flags, or via "set poslog" in your .nanorc.
  * Also included are some fixes for compilation with g++, and better handling
    of issues writing the backup file, which should reduce the need for the
  'set allow_insecure_backup" nanorc option.
- Spec file updates:
  * More changes based on rpmdevtools templates and spec-cleaner run.
  * Changed License: to GPLv3+ and (GFDL or GPLv3+).
  * Added description for the patch based on openSUSE Patches Guidelines.
  * Updates in Buildrequires: and Requires: sections.
  * Added Recommends: for the lang package.
  * Updated Authors: data.
  * Updates in %%install section. Manually install the doc files in order to
    easily split them between the main and lang package.
  * Removed %%check section (the package doesn't implement "make check").
  * Use %%preun instead of %%postun for "install_info".
* Sat Jan  1 2011 asterios.dramis@gmail.com
- Update to version 2.2.6
  * This is just a small release to update a bug where restricted mode was not
    particularly restricted since key bindings were introduced.
- Spec file changes after spec-cleaner run.
* Tue Aug 31 2010 cristian.rodriguez@opensuse.org
- Update to version 2.2.5
  * This release includes slightly less restrictive checkng
    when writing files in strange environments
  * Also included are some syntax highlighting updated
- Do not provide build dates in binaries
* Thu Apr 15 2010 pascal.bleser@opensuse.org
- update to 2.2.4:
  * security fixes due to an assessment of nano's vulnerability to
    symlink attacks on open files; the CVEs fixed with this release
    are CVE-2010-1160 and CVE-2010-1161
  * fixes for various crash modes when using the spell checker on
    new files in multibuffer mode
  * fix for the 'file was modified' message when saving to a new
    filename
  * fixes to page up/down due to the soft wrapping code
  * new syntax higlighting definition for cmake-related files
- changes from 2.2.3:
  * fix for paging up/down with smooth scrolling causing the cursor
    position not being preserved due to a bug in 2.2.2
* Sun Jan 24 2010 bitshuffler@opensuse.org
- Updated to 2.2.2
- Removed generic INSTALL file
- Split of -lang subpackage
* Tue Dec  1 2009 crrodriguez@opensuse.org
- update to nano 2.2.0 (stable release)
* Mon Nov 23 2009 crrodriguez@novell.com
- update to version 2.1.99pre2
* Sun Oct 11 2009 crrodriguez@opensuse.org
- --enable-debug for a while..
* Wed Sep 30 2009 crrodriguez@opensuse.org
- correct voidreturn patch
* Tue Sep 29 2009 crrodriguez@suse.de
- cleanup spec file a bit
- fix voidreturn
* Mon Sep 21 2009 crrodriguez@suse.de
- update to version 2.1.11
- tag localized man pages correctly
* Sat Sep  5 2009 crrodriguez@suse.de
- update to version 2.1.10 see NEWS for details
* Wed Feb 18 2009 crrodriguez@suse.de
- update to version 2.1.9 see NEWS for details
  * Issues with the new sped-up syntax highlighting code were
  corrected. Other fixes include configure-time detection of groff HTML
  support before attempting to generate the HTML version of man pages. Using
  ~ or ~username syntax in .nanorc should now work again. Also, nano will now
  only ask for one acknowledgment of errors it encounters when parsing nanorc
  files, and a new -q (--quiet) flag will silence these messages altogether.
* Mon Jan  5 2009 crrodriguez@suse.de
- update to versison 2.1.7, see NEWS for details
* Wed Sep  3 2008 crrodriguez@suse.de
- upgrade to nano 2.1.5, change list too long see ChangeLog
  for more details
* Tue Aug 26 2008 cthiel@suse.de
- update to version 2.0.8
  * GNU nano 2.0.8 is what she said.  This release contains fixes for
    several long standing issues, including: crashing when starting with too
    small a window size, compilation fixes for AIX curses, crashes in the
    help menu using some locales, and a fun issue where nano mistalenly
    reports a successful file write on filesystems which are almost
    completely full.  Have at it.
* Mon May  5 2008 crrodriguez@suse.de
- fix for Feature No 300498 , use RPM_OPT_FLAGS everywhere.
* Thu Apr 10 2008 cthiel@suse.de
- adapt package to use latests ncursesw
* Sun Feb 24 2008 crrodriguez@suse.de
- use find_lang macro
- add missing calls to install_info_* macros
* Fri Dec 21 2007 cthiel@suse.de
  * update to version 2.0.7
  * nano 2.0.7 keeps its balance.  This release fixes several bugs, among
    others: a segfault and several cursor positioning problems when
    uncutting text or inserting files into the current buffer; a problem
    where the total number of characters would be miscalculated when
    replacing single-byte characters with multibyte ones; several minor
    issues with the statusbar prompt involving text display and mouse
    support; and several oddities when tab-completing in the middle of a
    line.  It also improves autodetection of DOS and Mac format files,
    properly supports the mouse wheel when using a version of ncurses built
    with the --enable-ext-mouse option, fixes some problems under NetBSD
    curses, adds a lot of translation updates, and adds more minor
    documentation updates.  Slang curses emulation support has also been
    changed to turn off all the options that --enable-tiny does, as it's
    hopelessly broken otherwise.  Finally, nano is now licensed under the
    GNU GPL version 3 or later, and its documentation is now dual-licensed
    under the GNU GPL version 3 or later and the GNU FDL version 1.2 or
    later.  Have fun.
* Thu Dec  6 2007 cthiel@suse.de
- added nano-2.0.6.patch to fix error: call to '__open_missing_mode'
  declared with attribute error: open with O_CREAT in second argument needs
  3 arguments
* Thu May  3 2007 cthiel@suse.de
- update to version 2.0.6
  * GNU nano 2.0.6 "that was quick" is released.  This release fixes a
    potential segfault after justifying text marked from the bottom up.  It
    also adds one more minor documentation update.  Enjoy.
* Sun Apr 22 2007 cthiel@suse.de
- update to version 2.0.5
  * GNU nano 2.0.5 braces for impact.  Among other things, this release
    fixes various problems (including a segfault) when trying to open or
    save a file in a directory beginning with "~" that isn't a home
    directory; fixes a problem where a file with no name could be saved over
    an existing filename with no warning about overwriting it; properly
    disallows opening directories or device files from "include" commands in
    nanorc files; no longer displays a misleading prompt when trying to save
    in restricted mode with the mark on; and properly supports the Cancel
    and Shift-Cancel keys.  It also improves several color syntaxes to
    highlight trailing whitespace, just as the Java syntax does, and adds
    yet more minor documentation updates.  Have fun.
* Sat Apr  7 2007 cthiel@suse.de
- update to version 2.0.4
  * GNU nano 2.0.4 heralds the dawn.  This release contains proper support
    for the Ctrl-[arrow key], Shift-[arrow key], and F13-F16 keys under
    Xfce's Terminal.  It also adds still more minor documentation updates.
    Enjoy.
* Thu Mar 29 2007 cthiel@suse.de
- fixed build by adding BuildRequires: ncurses-devel
* Mon Jan 29 2007 cthiel@suse.de
- update to version 2.0.3
  * GNU nano 2.0.3 flows toward its ending.  This release contains several
    minor optimizations to make the executable a little smaller under some
    circumstances, some translation updates, improvements to the color
    syntax for Python, and still more minor documentation updates.
* Thu Dec 21 2006 cthiel@suse.de
- update to version 2.0.2
  * GNU nano 2.0.2 forges ahead.  This release fixes a segfault when trying
    to save in a nonexistent directory; fixes handling of strings containing
    nulls at the "Write File", "Insert File", "Execute Command", and "Go to
    Directory" prompts; fixes several minor memory leaks; fixes two more
    potential compilation warnings; adds a few translation updates; and adds
    a few more minor documentation updates.  Enjoy.
* Mon Nov 20 2006 cthiel@suse.de
- update to version 2.0.1
  * GNU nano 2.0.1 emerges from its cocoon.  This release contains several
    bugfixes: saving one file over another will now always warn about
    overwriting it, overwriting a file is no longer possible when saving a
    new file in restricted mode, and zero-length Unicode characters are now
    highlighted properly when nano is built without regular expression
    support.  It also adds several minor documentation updates.  Have fun
    with it.
* Sun Nov 12 2006 cthiel@suse.de
- update to version 2.0.0
  * GNU nano 2.0.0 does its little dance.  This release adds documentation
    updates and a few cosmetic tweaks.  For those who haven't been following
    nano 1.3 development, there are a ton of new features, including support
    for UTF-8, moving to a specified line and column instead of just a line,
    improved color syntax highlighting, inserting previously untypeable
    characters using "Verbatim Input" mode, and copying text into the
    cutbuffer without cutting it.  There are also fixes for some
    long-standing bugs, such as the "NumLock glitch" from nano 1.2.x, and
    the inability to unjustify text after resizing.  Finally, there are also
    a ton of translation updates and new translations, as well as new color
    syntaxes.  See the UPGRADE file for more information, and enjoy the new
    stable release.
* Mon Jun 26 2006 cthiel@suse.de
- update to version 1.3.12
  * This release contains the last new features that nano will have before
    2.0: copying text into the cutbuffer without cutting it, indenting lines
    of marked text with a single keystroke, reworked help text that should
    be easier for new users, searching for filenames in the file browser,
    the ability to include color regexes in files separate from nanorc
    files, etc.  It also contains many bugfixes.  Text can now be
    unjustified after justifying it and resizing the window; the screen is
    now cleared when suspending; the "default" color syntax is now handled
    properly at all times; lines of text containing tabs are now wrapped at
    the right place; double-column characters are now properly displayed
    when past the right edge of the screen; invalid multi-line color regexes
    are now ignored; and so on.
* Thu May 25 2006 cthiel@suse.de
- update to version 1.3.11
  * This release focuses mostly on bugfixes, which include better handling
    of the cursor at the statusbar prompt, support for certain combinations
    of Shift and keyboard keys in both normal and
  - -rebind-keypad mode, a fix for a minor display problem after some
    searches, a real fix for a long-standing segfault when displaying overly
    long lines, and a real fix for nano's not hanging up properly in xterm
    under certain circumstances.  There are also several new features, such
    as the ability to set the characters used as brackets when searching for
    matching brackets, and tab completion of directories at the "Go To
    Directory" prompt.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Dec 24 2005 cthiel@suse.de
- update to version 1.3.10
* Tue Oct 25 2005 cthiel@suse.de
- update to version 1.3.9
* Tue Sep 13 2005 cthiel@suse.de
- specfile cleanup
* Fri Jul  1 2005 cthiel@suse.de
- update to version 1.3.8
* Wed Jun 29 2005 cthiel@suse.de
- update to version 1.3.7
* Mon Jun  6 2005 cthiel@suse.de
- initial package (1.2.5)
